<?php
/**
 * Web template page class
 *
 * This file defines YSWErrorEN class.
 * It includes methods to send web template page data.
 *
 * @package YggDore.Server.BaseWeb.Theme.EN
 * @author YggDore Co.,Ltd.
 */



/**
 * Require YggDore config file
 */
require_once( "YggDore/Base/Config.php" );
/**
 * Require YggHTML class
 */
require_once( "YggDore/Base/YggHTML.php" );
/**
 * Require YggTool class
 */
require_once( "YggDore/Base/YggTool.php" );
/**
 * Require YggExceptionTool class
 */
require_once( "YggDore/Base/YggExceptionTool.php" );
/**
 * Require YggRuntimeException class
 */
require_once( "YggDore/Base/YggRuntimeException.php" );
/**
 * Require YggDore server config file
 */
require_once( "YggDore/Server/Config/Config.php" );
/**
 * Require YSWBaseEN class
 */
require_once( "YggDore/Server/BaseWeb/Theme/EN/YSWBaseEN.php" );


/**
 * Error web page creation class
 *
 * This class has methods to send error web page data.
 *
 * <code>
 * YSWErrorEN::send();
 * </code>
 *
 * @package YggDore.Server.BaseWeb.Theme.EN
 */
class YSWErrorEN {
	/**
	 * Send error web page
	 *
	 * Send error web page XHTML to client.
	 * Error message is created by $e.
	 * If $e is specified NULL, $e is as same as Exception.
	 *
	 * @param Exception $e Exception
	 */
	public static function send( $e = null )
	{
		if( $e === null ){
			$e = new Exception;
		}

		self::sendMsg( self::convException( $e ) );
	}


	/**
	 * Send error web page 
	 *
	 * $msg is sent to client.
	 *
	 * @param string $msg Message
	 */
	public static function sendMsg( $msg )
	{
		if( $msg == "" ){
			throw new UnexpectedValueException;
		}

		$bw = new YSWBaseEN;

		$prefix = $bw->getPrefix();
		$cpfx   = YggHTML::specialChars( $prefix->getCurrent() );
		$hpfx   = YggHTML::specialChars( $prefix->getHTTP() );

		$bw->sendHeader( "Error" );
		$bw->sendBody();

?><div class="error"><?php echo YggHTML::specialChars( $msg ); ?></div><?php

		$bw->sendFooter();
	}


	/**
	 * Convert exception to message
	 *
	 * $e is converted to message.
	 *
	 * @param Exception $e Exception
	 */
	public static function convException( $e = null )
	{
		if( $e === null ){
			$e = new Exception;
		}

		return YggExceptionTool::caseClass( $e, self::getECI() );
	}


	/**
	 * Get table to convert exception to message
	 *
	 * @return array
	 */
	public static function getECI()
	{
		return array(
			"case" => array(
				"RuntimeException" =>
					"The error occurred while executing program, " .
					"and processing was interrupted. " .
					"Please wait for time and access again.",
				"YggRuntimeException" =>
					"There are problems with the information you provided. " .
					"Please fix error(s) highlighted below."
			),
			"default" =>
				"Illegal processing was occurred. " . 
				"Please wait for time and access again."
		);
	}
}
?>
